__version__ = '0.3.3'

import random
from termcolor import colored, cprint

import time
from art import *
import os
import json
pathToScript = os.path.dirname(os.path.abspath(__file__))




from Morpion.datas import variables, loading, setGrid, getPlayers, notDone, isWinner
vars = variables()
colors = vars.colors
cases = vars.scheme
title = vars.title



global grid1
global grid2
global grid3
global grid4
global grid5

global joueurs
joueurs = []
'''
bleu     0
vert     1
rouge    2
jaune    3 
cyan     4
gris     5
'''


global Player1
Player1 = colored("X", colors[2])
global Player2
Player2 = colored("O", colors[0])



global coup
coup = 0

global casesDispo
casesDispo = []

            
def getCoup(p, casesDispo) -> int:
    coup = "test"
    while not str(coup) in str(casesDispo):
        coup = input(f'{p}, quelle case veux-tu marquer ?  ')
        if coup == "":
            coup = "lol"
        try:
            coup = int(coup)
        except ValueError:
            print('Choisi une case disponible (numéros visibles)')
            pass
    return coup 
    
    
    
    """
    #print(casesDispo) 
    coup = input(f'{p}, quelle case veux-tu marquer ?  ')
    try:
        coup = int(coup)
        if str(coup) in str(casesDispo):
            return coup
        else:
            print('Choisi une case disponible (numéros visibles)')
            return getCoup(p, casesDispo)
    except ValueError:
        print('Choisi un des nombres disponible (numéros visibles)')
        getCoup(p, casesDispo)"""


def setGame(joueurs, gameManager):

    for p in gameManager['currentPlayers']:
        joueurs.append(p)
    grid = setGrid(1, 0, 0)
    os.system('clear')
    for ligne in grid:
        print(ligne)
    game(joueurs, gameManager)

def game(joueurs, gameManager):
    casesDispo = [1, 2, 3, 4, 5, 6, 7, 8, 9] 
    turn = 1
    p1 = random.choice(joueurs)
    #print(joueurs)
    p2 = random.choice(joueurs)
    while p2== p1:
        p2 = random.choice(joueurs)
    while notDone(turn):
        turn = turn+1
        if turn%2 == 1:
            p = p1
        else:
            p = p2
        
        coup = getCoup(p, casesDispo)
        try:
            casesDispo.remove(coup)
        except ValueError:
            pass
        #print(casesDispo)
        
        if turn%2 == 1:
            newGrid = setGrid(turn, coup, Player1)
        else:
            newGrid = setGrid(turn, coup, Player2)
        os.system('clear')
        for ligne in newGrid:
            print(ligne)



    time.sleep(2)
    os.system('clear')
    tprint('Game over')
    """print(p)
    print(type(p))
    print(p1)
    print(type(p1))
    print(p2)
    print(type(p2))
    print(gameManager)"""

    p1stats = gameManager[str(p1)]
    
    p2stats = gameManager[str(p2)]
    
    if isWinner() == False:
        trun = 9
    else: 
        turn = 11


    if turn == 11:
        p1stats[2] = p1stats[2] + 1
        p2stats[2] = p2stats[2] + 1
        cprint('Match nul, bien joué à tous les deux !', 'yellow')
    elif p == p1:
        p1stats[0] = p1stats[0] + 1
        p2stats[1] = p2stats[1] + 1
        print(colored(f"Félicitation {p}, tu as gagné ! ", 'yellow'))
    elif p == p2:
        p1stats[1] = p1stats[1] + 1
        p2stats[0] = p2stats[0] + 1
        print(colored(f"Félicitation {p}, tu as gagné ! ", 'yellow'))
    
    gameManager[p1] = p1stats
    gameManager[p2] = p2stats

    with open('save.json', 'w', encoding='utf-8') as file:
        json.dump(gameManager, file)

    print(colored(f"\nSTATS :\n", 'red'))   
    print(f"{p1} : {p1stats[0]} victoires, {p1stats[1]} défaites, {p1stats[2]} matchs nuls   ")
    print(f"{p2} : {p2stats[0]} victoires, {p2stats[1]} défaites, {p2stats[2]} matchs nuls   ")
    print("\nVoulez vous rejouer ?")
    print("1) Quitter le jeu")
    print("2) Rejouer")
    print("3) Changer de joueurs")  
    def endGameChoice() -> str:
        choice = input("")
        if choice == "1" or choice == "2" or choice == "3":
            return choice
        else:
            return endGameChoice()
    mode = int(endGameChoice())
    if mode == 1:
        os.system("""
        osascript -e 'tell application "Terminal" to close first window' && exit
        """)
    elif mode == 2:
        setGame([], gameManager)

    elif mode ==3 :
        os.system('clear')
        players = []
        temp = getPlayers()
        for p in temp.keys():
            players.append(p)
        setGame(players, gameManager)




if __name__ == "__main__":
    loading()
    os.system('clear')
    #pathToScript = os.path.dirname(os.path.abspath(__file__))
    #print(pathToScript)
    gameManager = getPlayers()
    setGame(joueurs, gameManager)
    



from termcolor import colored
from art import *
import os
import time
import json

class variables():
    def __init__(self):
        self.colors = ['blue', 'green', 'red', 'yellow','cyan', 'grey']
        self.title = ["Morpion", ""]
        self.scheme = ["debug", colored("1", 'green'), colored("2", 'green'), colored("3", 'green'), colored("4", 'green'), colored("5", 'green'), colored("6", 'green'), colored("7", 'green'), colored("8", 'green'), colored("9", 'green')]
        self.cases = self.scheme


def loadFormat(x, base=2) -> int:
    return base * round(x/base)

def loading():
    os.system("clear")
    tprint("morpion")
    fill = colored('■', "blue")
    percent = 0
    

    for progress in range(0, 1020):
        progress = progress/10
        percent = progress
        bar = f"Loading  |---------------------------------------------------| {percent} %" #11
        progress = loadFormat(progress)
        if progress!= 0:
            progress = int(progress/2)
            bar = bar.replace('-', fill, progress)
            print(f"{bar}", end="\r")
        else:
            print(f"{bar}", end='\r')
        time.sleep(0.001)
    percent = 100
    bar = f"Loading  |{fill*50}| 100 %        "
    print(bar)
    time.sleep(2)
    os.system('clear')

global cases
cases = []

def setGrid(turn, case, value) ->list:
    global cases
    vars = variables()
    if turn == 1:
        cases = vars.cases
    else:
        cases[case] = value
    global grid1
    global grid2
    global grid3
    global grid4
    global grid5
    grid1 = f"{cases[1]} | {cases[2]} | {cases[3]}"
    grid2 = "--+---+--"
    grid3 = f"{cases[4]} | {cases[5]} | {cases[6]}       tour {turn}"        
    grid4 = "--+---+--"
    grid5 = f"{cases[7]} | {cases[8]} | {cases[9]}"
    return [grid1, grid2, grid3, grid4, grid5]


def getPlayers() -> dict:
    with open('Morpion/save.json', 'r') as save:
        players = {}
        #récupérer les données des joueurs précédents
        players = json.load(save)
        #j1
        p1 = input('Joueur 1, qui êtes vous ?\n')
        if players.get(p1):
            print(f'Content de de te revoir {p1} ')
        else:
            players[p1] = [0, 0, 0]
            print(f'Bienvenue {p1}')
        #j2
        #os.system('clear')
        def P2(p1) -> str:
            p2 = input('Joueur 2, qui êtes vous ?\n')
            if p2 == p1:
                print('Joueur déja dans la partie, entrez un autre nom.')
                return P2(p1)
            else:
                return p2

        p2 = P2(p1)
        if players.get(p2):
            print(f'Content de de te revoir {p2} ')
        else:
            players[p2] = [0, 0, 0]
            print(f'Bienvenue {p2}')
    players['currentPlayers'] = [p1, p2]
    #print(players)
    time.sleep(1.0)
    return players
        
def notDone(turn) -> bool:
    
    global cases
    if cases[1] == cases[2] == cases[3] == cases[4] == cases[5] == cases[6] == cases[7] == cases[8] == cases[9]:
        return True
    elif turn == 10:
        return False
    elif cases[1] == cases[2] == cases[3]:
        return False
    elif cases[4] == cases[5] == cases[6]:
        return False
    elif cases[7] == cases[8] == cases[9]:
        return False
    elif cases[1] == cases[4] == cases[7]:
        return False
    elif cases[2] == cases[5] == cases[8]:
        return False
    elif cases[3] == cases[6] == cases[9]:
        return False
    elif cases[1] == cases[5] == cases[9]:
        return False
    elif cases[3] == cases[5] == cases[7]:
        return False
    else:
        return True

def isWinner() -> bool:
    if cases[1] == cases[2] == cases[3]:
        return False
    elif cases[4] == cases[5] == cases[6]:
        return False
    elif cases[7] == cases[8] == cases[9]:
        return False
    elif cases[1] == cases[4] == cases[7]:
        return False
    elif cases[2] == cases[5] == cases[8]:
        return False
    elif cases[3] == cases[6] == cases[9]:
        return False
    elif cases[1] == cases[5] == cases[9]:
        return False
    elif cases[3] == cases[5] == cases[7]:
        return False
    else:
        return True

    